@@ -37,6 +37,9 @@ function(mdf,fixform = Ymat ~ 1,components=c("VarE(I)","VarG(Ia)"),cohortform=NU
   if(is.null(mdf$rel)) {
     df <- mdf
     cat("Data file is a normal dataframe:\n")
+    if(relmat == "withdf") {
+      stop("dmm: cant have 'relmat=withdf' option for a normal dataframe\n")
+    }
   }
   else {
     df <- mdf$df
@@ -131,7 +134,7 @@ function(mdf,fixform = Ymat ~ 1,components=c("VarE(I)","VarG(Ia)"),cohortform=NU
   b <- qr.coef(x.qr,am$y)
   krank <- x.qr$rank
   if(krank < am$k) {
-    stop("Rank of X .ne. k:",krank,am$k,"\n")
+    stop("Rank of X ",krank," .ne. no of fixed effects ",am$k,"\n")
   }
 # cat("OLS AOV Estimates of b:\n")
 # print(b)  # b here is k x l
